@@ -71,7 +71,7 @@ def ansi2latex(text):
     return _ansi2anything(text, _latexconverter)
 
 
-def _htmlconverter(fg, bg, bold, underline, inverse):
+def _htmlconverter(fg, bg, bold, underline, inverse):  # noqa
     """
     Return start and end tags for given foreground/background/bold/underline.
 
@@ -114,7 +114,7 @@ def _htmlconverter(fg, bg, bold, underline, inverse):
     return starttag, "</span>"
 
 
-def _latexconverter(fg, bg, bold, underline, inverse):
+def _latexconverter(fg, bg, bold, underline, inverse):  # noqa
     """
     Return start and end markup given foreground/background/bold/underline.
 
@@ -133,7 +133,7 @@ def _latexconverter(fg, bg, bold, underline, inverse):
     elif fg:
         # See http://tex.stackexchange.com/a/291102/13684
         starttag += r"\def\tcRGB{\textcolor[RGB]}\expandafter"
-        starttag += r"\tcRGB\expandafter{\detokenize{%s,%s,%s}}{" % fg
+        starttag += r"\tcRGB\expandafter{{\detokenize{{{},{},{}}}}}{{".format(*fg)
         endtag = "}" + endtag
     elif inverse:
         starttag += r"\textcolor{ansi-default-inverse-fg}{"
@@ -147,7 +147,7 @@ def _latexconverter(fg, bg, bold, underline, inverse):
         starttag += r"\setlength{\fboxsep}{0pt}"
         # See http://tex.stackexchange.com/a/291102/13684
         starttag += r"\def\cbRGB{\colorbox[RGB]}\expandafter"
-        starttag += r"\cbRGB\expandafter{\detokenize{%s,%s,%s}}{" % bg
+        starttag += r"\cbRGB\expandafter{{\detokenize{{{},{},{}}}}}{{".format(*bg)
         endtag = r"\strut}" + endtag
     elif inverse:
         starttag += r"\setlength{\fboxsep}{0pt}"
@@ -203,7 +203,7 @@ def _ansi2anything(text, converter):  # noqa
 
         if chunk:
             starttag, endtag = converter(
-                fg + 8 if bold and fg in range(8) else fg,  # type:ignore
+                fg + 8 if bold and fg in range(8) else fg,  # type:ignore[operator]
                 bg,
                 bold,
                 underline,
